@@ -383,6 +383,9 @@ class HathiPreservation(models.Model):
                         bf = row[19]
                         unknown_format = False
 
+                        # check if it's an ISSN
+                        logging.info('ISSN: {}'.format(issn))
+
                         # if it's a serial, try to parse the vols
                         if bf == 'SE' and issn and vols:
                             matches = re.findall(volume_matcher, vols)
