@@ -127,10 +127,10 @@ def generic_lockss_import(url: str, model,
 
         for row in csv_reader:
             # trim the publisher field if needed
-            publisher = row['Publisher'][:254]
+            publisher_name = row['Publisher'][:254]
 
             publisher, created = \
-                Publisher.objects.get_or_create(name=row['Publisher'])
+                Publisher.objects.get_or_create(name=publisher_name)
 
             if model.name() == 'CLOCKSS' or model.name() == 'LOCKSS'\
                     or model.name() == 'Cariniana':
